@@ -1,30 +1,43 @@
 import os
 from traitlets import Unicode
 from ipywidgets import Widget
+
+from .VueComponentRegistry import vue_component_files, register_component_from_file
 from ._version import semver
 
 template_registry = {}
 
 
-def watch(path=''):
+def watch(paths=""):
     import logging
     from watchdog.observers import Observer
     from watchdog.events import FileSystemEventHandler
 
-    log = logging.getLogger('ipyvue')
+    log = logging.getLogger("ipyvue")
+
     class VueEventHandler(FileSystemEventHandler):
         def on_modified(self, event):
             super(VueEventHandler, self).on_modified(event)
             if not event.is_directory:
                 if event.src_path in template_registry:
-                    log.info(f'updating: {event.src_path}')
+                    log.info(f"updating: {event.src_path}")
                     with open(event.src_path) as f:
                         template_registry[event.src_path].template = f.read()
+                elif event.src_path in vue_component_files:
+                    log.info(f"updating component: {event.src_path}")
+                    name = vue_component_files[event.src_path]
+                    register_component_from_file(name, event.src_path)
 
     observer = Observer()
-    path = os.path.normpath(path)
-    log.info(f'watching {path}')
-    observer.schedule(VueEventHandler(), path, recursive=True)
+
+    if not isinstance(paths, (list, tuple)):
+        paths = [paths]
+
+    for path in paths:
+        path = os.path.normpath(path)
+        log.info(f"watching {path}")
+        observer.schedule(VueEventHandler(), path, recursive=True)
+
     observer.start()
 
 
@@ -34,16 +47,18 @@ def get_template(abs_path):
         with open(abs_path) as f:
             tw = Template(template=f.read())
             template_registry[abs_path] = tw
-
+    else:
+        with open(abs_path) as f:
+            template_registry[abs_path].template = f.read()
     return template_registry[abs_path]
 
 
 class Template(Widget):
-    _model_name = Unicode('TemplateModel').tag(sync=True)
-    _model_module = Unicode('jupyter-vue').tag(sync=True)
+    _model_name = Unicode("TemplateModel").tag(sync=True)
+    _model_module = Unicode("jupyter-vue").tag(sync=True)
     _model_module_version = Unicode(semver).tag(sync=True)
 
     template = Unicode(None, allow_none=True).tag(sync=True)
 
 
-__all__ = ['Template', 'watch']
+__all__ = ["Template", "watch"]
